@@ -34,17 +34,12 @@
 /*
  * "nodedev-create" command
  */
-static const vshCmdInfo info_node_device_create[] = {
-    {.name = "help",
-     .data = N_("create a device defined "
-                "by an XML file on the node")
-    },
-    {.name = "desc",
-     .data = N_("Create a device on the node.  Note that this "
+static const vshCmdInfo info_node_device_create = {
+     .help = N_("create a device defined "
+                "by an XML file on the node"),
+     .desc = N_("Create a device on the node.  Note that this "
                 "command creates devices on the physical host "
-                "that can then be assigned to a virtual machine.")
-    },
-    {.name = NULL}
+                "that can then be assigned to a virtual machine."),
 };
 
 static const vshCmdOptDef opts_node_device_create[] = {
@@ -66,7 +61,7 @@ cmdNodeDeviceCreate(vshControl *ctl, const vshCmd *cmd)
     virshControl *priv = ctl->privData;
     unsigned int flags = 0;
 
-    if (vshCommandOptStringReq(ctl, cmd, "file", &from) < 0)
+    if (vshCommandOptString(ctl, cmd, "file", &from) < 0)
         return false;
 
     if (virFileReadAll(from, VSH_MAX_XML_FILE, &buffer) < 0)
@@ -89,15 +84,10 @@ cmdNodeDeviceCreate(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-destroy" command
  */
-static const vshCmdInfo info_node_device_destroy[] = {
-    {.name = "help",
-     .data = N_("destroy (stop) a device on the node")
-    },
-    {.name = "desc",
-     .data = N_("Destroy a device on the node.  Note that this "
-                "command destroys devices on the physical host")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_destroy = {
+     .help = N_("destroy (stop) a device on the node"),
+     .desc = N_("Destroy a device on the node.  Note that this "
+                "command destroys devices on the physical host"),
 };
 
 static const vshCmdOptDef opts_node_device_destroy[] = {
@@ -106,8 +96,9 @@ static const vshCmdOptDef opts_node_device_destroy[] = {
      .help = "device"
     },
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device name or wwn pair in 'wwnn,wwpn' format"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -151,7 +142,7 @@ cmdNodeDeviceDestroy(vshControl *ctl, const vshCmd *cmd)
     g_autoptr(virshNodeDevice) dev = NULL;
     const char *device_value = NULL;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &device_value) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &device_value) < 0)
         return false;
 
     dev = vshFindNodeDevice(ctl, device_value);
@@ -362,14 +353,9 @@ virshNodeDeviceListCollect(vshControl *ctl,
 /*
  * "nodedev-list" command
  */
-static const vshCmdInfo info_node_list_devices[] = {
-    {.name = "help",
-     .data = N_("enumerate devices on this host")
-    },
-    {.name = "desc",
-     .data = ""
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_list_devices = {
+    .help = N_("enumerate devices on this host"),
+    .desc = "",
 };
 
 static const vshCmdOptDef opts_node_list_devices[] = {
@@ -379,6 +365,7 @@ static const vshCmdOptDef opts_node_list_devices[] = {
     },
     {.name = "cap",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .completer = virshNodeDeviceCapabilityNameCompleter,
      .help = N_("capability names, separated by comma")
     },
@@ -577,21 +564,17 @@ cmdNodeListDevices(vshControl *ctl, const vshCmd *cmd G_GNUC_UNUSED)
 /*
  * "nodedev-dumpxml" command
  */
-static const vshCmdInfo info_node_device_dumpxml[] = {
-    {.name = "help",
-     .data = N_("node device details in XML")
-    },
-    {.name = "desc",
-     .data = N_("Output the node device details as an XML dump to stdout.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_dumpxml = {
+    .help = N_("node device details in XML"),
+    .desc = N_("Output the node device details as an XML dump to stdout."),
 };
 
 
 static const vshCmdOptDef opts_node_device_dumpxml[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device name or wwn pair in 'wwnn,wwpn' format"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -601,7 +584,6 @@ static const vshCmdOptDef opts_node_device_dumpxml[] = {
     },
     {.name = "xpath",
      .type = VSH_OT_STRING,
-     .flags = VSH_OFLAG_REQ_OPT,
      .completer = virshCompleteEmpty,
      .help = N_("xpath expression to filter the XML document")
     },
@@ -622,7 +604,7 @@ cmdNodeDeviceDumpXML(vshControl *ctl, const vshCmd *cmd)
     bool wrap = vshCommandOptBool(cmd, "wrap");
     const char *xpath = NULL;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &device_value) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &device_value) < 0)
          return false;
 
     if (vshCommandOptStringQuiet(ctl, cmd, "xpath", &xpath) < 0)
@@ -645,26 +627,23 @@ cmdNodeDeviceDumpXML(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-detach" command
  */
-static const vshCmdInfo info_node_device_detach[] = {
-    {.name = "help",
-     .data = N_("detach node device from its device driver")
-    },
-    {.name = "desc",
-     .data = N_("Detach node device from its device driver before assigning to a domain.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_detach = {
+    .help = N_("detach node device from its device driver"),
+    .desc = N_("Detach node device from its device driver before assigning to a domain."),
 };
 
 
 static const vshCmdOptDef opts_node_device_detach[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device key"),
      .completer = virshNodeDeviceNameCompleter,
     },
     {.name = "driver",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .completer = virshNodeDevicePCIBackendCompleter,
      .help = N_("pci device assignment backend driver (e.g. 'vfio' or 'xen')")
     },
@@ -680,7 +659,7 @@ cmdNodeDeviceDetach(vshControl *ctl, const vshCmd *cmd)
     bool ret = true;
     virshControl *priv = ctl->privData;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &name) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &name) < 0)
         return false;
 
     ignore_value(vshCommandOptStringQuiet(ctl, cmd, "driver", &driverName));
@@ -712,21 +691,17 @@ cmdNodeDeviceDetach(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-reattach" command
  */
-static const vshCmdInfo info_node_device_reattach[] = {
-    {.name = "help",
-     .data = N_("reattach node device to its device driver")
-    },
-    {.name = "desc",
-     .data = N_("Reattach node device to its device driver once released by the domain.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_reattach = {
+    .help = N_("reattach node device to its device driver"),
+    .desc = N_("Reattach node device to its device driver once released by the domain."),
 };
 
 
 static const vshCmdOptDef opts_node_device_reattach[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device key"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -741,7 +716,7 @@ cmdNodeDeviceReAttach(vshControl *ctl, const vshCmd *cmd)
     bool ret = true;
     virshControl *priv = ctl->privData;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &name) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &name) < 0)
         return false;
 
     if (!(device = virNodeDeviceLookupByName(priv->conn, name))) {
@@ -762,21 +737,17 @@ cmdNodeDeviceReAttach(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-reset" command
  */
-static const vshCmdInfo info_node_device_reset[] = {
-    {.name = "help",
-     .data = N_("reset node device")
-    },
-    {.name = "desc",
-     .data = N_("Reset node device before or after assigning to a domain.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_reset = {
+    .help = N_("reset node device"),
+    .desc = N_("Reset node device before or after assigning to a domain."),
 };
 
 
 static const vshCmdOptDef opts_node_device_reset[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device key"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -791,7 +762,7 @@ cmdNodeDeviceReset(vshControl *ctl, const vshCmd *cmd)
     bool ret = true;
     virshControl *priv = ctl->privData;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &name) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &name) < 0)
         return false;
 
     if (!(device = virNodeDeviceLookupByName(priv->conn, name))) {
@@ -906,24 +877,21 @@ virshNodeDeviceEventCallback virshNodeDeviceEventCallbacks[] = {
 G_STATIC_ASSERT(VIR_NODE_DEVICE_EVENT_ID_LAST == G_N_ELEMENTS(virshNodeDeviceEventCallbacks));
 
 
-static const vshCmdInfo info_node_device_event[] = {
-    {.name = "help",
-     .data = N_("Node Device Events")
-    },
-    {.name = "desc",
-     .data = N_("List event types, or wait for node device events to occur")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_event = {
+    .help = N_("Node Device Events"),
+    .desc = N_("List event types, or wait for node device events to occur"),
 };
 
 static const vshCmdOptDef opts_node_device_event[] = {
     {.name = "device",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .help = N_("filter by node device name"),
      .completer = virshNodeDeviceNameCompleter,
     },
     {.name = "event",
      .type = VSH_OT_STRING,
+     .unwanted_positional = true,
      .completer = virshNodeDeviceEventNameCompleter,
      .help = N_("which event type to wait for")
     },
@@ -933,6 +901,7 @@ static const vshCmdOptDef opts_node_device_event[] = {
     },
     {.name = "timeout",
      .type = VSH_OT_INT,
+     .unwanted_positional = true,
      .help = N_("timeout seconds")
     },
     {.name = "list",
@@ -967,7 +936,7 @@ cmdNodeDeviceEvent(vshControl *ctl, const vshCmd *cmd)
         return true;
     }
 
-    if (vshCommandOptStringReq(ctl, cmd, "event", &eventName) < 0)
+    if (vshCommandOptString(ctl, cmd, "event", &eventName) < 0)
         return false;
     if (!eventName) {
         vshError(ctl, "%s", _("either --list or --event <type> is required"));
@@ -989,7 +958,7 @@ cmdNodeDeviceEvent(vshControl *ctl, const vshCmd *cmd)
     data.cb = &virshNodeDeviceEventCallbacks[event];
     if (vshCommandOptTimeoutToMs(ctl, cmd, &timeout) < 0)
         return false;
-    if (vshCommandOptStringReq(ctl, cmd, "device", &device_value) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &device_value) < 0)
         return false;
 
     if (device_value) {
@@ -1034,20 +1003,16 @@ cmdNodeDeviceEvent(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-undefine" command
  */
-static const vshCmdInfo info_node_device_undefine[] = {
-    {.name = "help",
-     .data = N_("Undefine an inactive node device")
-    },
-    {.name = "desc",
-     .data = N_("Undefines the configuration for an inactive node device")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_undefine = {
+    .help = N_("Undefine an inactive node device"),
+    .desc = N_("Undefines the configuration for an inactive node device"),
 };
 
 static const vshCmdOptDef opts_node_device_undefine[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device name or wwn pair in 'wwnn,wwpn' format"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -1060,7 +1025,7 @@ cmdNodeDeviceUndefine(vshControl *ctl, const vshCmd *cmd G_GNUC_UNUSED)
     g_autoptr(virshNodeDevice) dev = NULL;
     const char *device_value = NULL;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &device_value) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &device_value) < 0)
         return false;
 
     dev = vshFindNodeDevice(ctl, device_value);
@@ -1081,16 +1046,11 @@ cmdNodeDeviceUndefine(vshControl *ctl, const vshCmd *cmd G_GNUC_UNUSED)
 /*
  * "nodedev-define" command
  */
-static const vshCmdInfo info_node_device_define[] = {
-    {.name = "help",
-     .data = N_("Define or modify a device by an xml file on a node")
-    },
-    {.name = "desc",
-     .data = N_("Defines or modifies a persistent device on the node that "
+static const vshCmdInfo info_node_device_define = {
+     .help = N_("Define or modify a device by an xml file on a node"),
+     .desc = N_("Defines or modifies a persistent device on the node that "
                 "can be assigned to a domain. The device must be started "
-                "before it can be assigned to a domain.")
-    },
-    {.name = NULL}
+                "before it can be assigned to a domain."),
 };
 
 static const vshCmdOptDef opts_node_device_define[] = {
@@ -1112,7 +1072,7 @@ cmdNodeDeviceDefine(vshControl *ctl, const vshCmd *cmd G_GNUC_UNUSED)
     virshControl *priv = ctl->privData;
     unsigned int flags = 0;
 
-    if (vshCommandOptStringReq(ctl, cmd, "file", &from) < 0)
+    if (vshCommandOptString(ctl, cmd, "file", &from) < 0)
         return false;
 
     if (virFileReadAll(from, VSH_MAX_XML_FILE, &buffer) < 0)
@@ -1135,20 +1095,16 @@ cmdNodeDeviceDefine(vshControl *ctl, const vshCmd *cmd G_GNUC_UNUSED)
 /*
  * "nodedev-start" command
  */
-static const vshCmdInfo info_node_device_start[] = {
-    {.name = "help",
-     .data = N_("Start an inactive node device")
-    },
-    {.name = "desc",
-     .data = N_("Starts an inactive node device that was previously defined")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_start = {
+    .help = N_("Start an inactive node device"),
+    .desc = N_("Starts an inactive node device that was previously defined"),
 };
 
 static const vshCmdOptDef opts_node_device_start[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device name"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -1163,7 +1119,7 @@ cmdNodeDeviceStart(vshControl *ctl, const vshCmd *cmd)
     bool ret = true;
     virshControl *priv = ctl->privData;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &name) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &name) < 0)
         return false;
 
     if (!(device = virNodeDeviceLookupByName(priv->conn, name))) {
@@ -1185,20 +1141,16 @@ cmdNodeDeviceStart(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-autostart" command
  */
-static const vshCmdInfo info_node_device_autostart[] = {
-    {.name = "help",
-     .data = N_("autostart a defined node device")
-    },
-    {.name = "desc",
-     .data = N_("Configure a node device to be automatically started at boot.")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_autostart = {
+    .help = N_("autostart a defined node device"),
+    .desc = N_("Configure a node device to be automatically started at boot."),
 };
 
 static const vshCmdOptDef opts_node_device_autostart[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device name or wwn pair in 'wwnn,wwpn' format"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -1216,7 +1168,7 @@ cmdNodeDeviceAutostart(vshControl *ctl, const vshCmd *cmd)
     const char *name = NULL;
     int autostart;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &name) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &name) < 0)
         return false;
 
     dev = vshFindNodeDevice(ctl, name);
@@ -1246,21 +1198,17 @@ cmdNodeDeviceAutostart(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-info" command
  */
-static const vshCmdInfo info_node_device_info[] = {
-    {.name = "help",
-     .data = N_("node device information")
-    },
-    {.name = "desc",
-     .data = N_("Returns basic information about the node device")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_info = {
+    .help = N_("node device information"),
+    .desc = N_("Returns basic information about the node device"),
 };
 
 
 static const vshCmdOptDef opts_node_device_info[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device name or wwn pair in 'wwnn,wwpn' format"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -1275,7 +1223,7 @@ cmdNodeDeviceInfo(vshControl *ctl, const vshCmd *cmd)
     int autostart;
     const char *parent = NULL;
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &device_value) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &device_value) < 0)
          return false;
 
     device = vshFindNodeDevice(ctl, device_value);
@@ -1302,20 +1250,16 @@ cmdNodeDeviceInfo(vshControl *ctl, const vshCmd *cmd)
 /*
  * "nodedev-update" command
  */
-static const vshCmdInfo info_node_device_update[] = {
-    {.name = "help",
-     .data = N_("Update a active and/or inactive node device")
-    },
-    {.name = "desc",
-     .data = N_("Updates the configuration of a node device")
-    },
-    {.name = NULL}
+static const vshCmdInfo info_node_device_update = {
+    .help = N_("Update a active and/or inactive node device"),
+    .desc = N_("Updates the configuration of a node device"),
 };
 
 static const vshCmdOptDef opts_node_device_update[] = {
     {.name = "device",
-     .type = VSH_OT_DATA,
-     .flags = VSH_OFLAG_REQ,
+     .type = VSH_OT_STRING,
+     .positional = true,
+     .required = true,
      .help = N_("device name or wwn pair in 'wwnn,wwpn' format"),
      .completer = virshNodeDeviceNameCompleter,
     },
@@ -1342,7 +1286,7 @@ cmdNodeDeviceUpdate(vshControl *ctl, const vshCmd *cmd)
     VSH_EXCLUSIVE_OPTIONS("current", "live");
     VSH_EXCLUSIVE_OPTIONS("current", "config");
 
-    if (vshCommandOptStringReq(ctl, cmd, "device", &device_value) < 0)
+    if (vshCommandOptString(ctl, cmd, "device", &device_value) < 0)
          return false;
 
     device = vshFindNodeDevice(ctl, device_value);
@@ -1350,7 +1294,7 @@ cmdNodeDeviceUpdate(vshControl *ctl, const vshCmd *cmd)
     if (!device)
         return false;
 
-    if (vshCommandOptStringReq(ctl, cmd, "file", &from) < 0)
+    if (vshCommandOptString(ctl, cmd, "file", &from) < 0)
         goto cleanup;
 
     if (virFileReadAll(from, VSH_MAX_XML_FILE, &xml) < 0)
@@ -1399,89 +1343,88 @@ const vshCmdDef nodedevCmds[] = {
     {.name = "nodedev-create",
      .handler = cmdNodeDeviceCreate,
      .opts = opts_node_device_create,
-     .info = info_node_device_create,
+     .info = &info_node_device_create,
      .flags = 0
     },
     {.name = "nodedev-destroy",
      .handler = cmdNodeDeviceDestroy,
      .opts = opts_node_device_destroy,
-     .info = info_node_device_destroy,
+     .info = &info_node_device_destroy,
      .flags = 0
     },
     {.name = "nodedev-detach",
      .handler = cmdNodeDeviceDetach,
      .opts = opts_node_device_detach,
-     .info = info_node_device_detach,
+     .info = &info_node_device_detach,
      .flags = 0
     },
     {.name = "nodedev-dettach",
-     .flags = VSH_CMD_FLAG_ALIAS,
      .alias = "nodedev-detach"
     },
     {.name = "nodedev-dumpxml",
      .handler = cmdNodeDeviceDumpXML,
      .opts = opts_node_device_dumpxml,
-     .info = info_node_device_dumpxml,
+     .info = &info_node_device_dumpxml,
      .flags = 0
     },
     {.name = "nodedev-list",
      .handler = cmdNodeListDevices,
      .opts = opts_node_list_devices,
-     .info = info_node_list_devices,
+     .info = &info_node_list_devices,
      .flags = 0
     },
     {.name = "nodedev-reattach",
      .handler = cmdNodeDeviceReAttach,
      .opts = opts_node_device_reattach,
-     .info = info_node_device_reattach,
+     .info = &info_node_device_reattach,
      .flags = 0
     },
     {.name = "nodedev-reset",
      .handler = cmdNodeDeviceReset,
      .opts = opts_node_device_reset,
-     .info = info_node_device_reset,
+     .info = &info_node_device_reset,
      .flags = 0
     },
     {.name = "nodedev-event",
      .handler = cmdNodeDeviceEvent,
      .opts = opts_node_device_event,
-     .info = info_node_device_event,
+     .info = &info_node_device_event,
      .flags = 0
     },
     {.name = "nodedev-define",
      .handler = cmdNodeDeviceDefine,
      .opts = opts_node_device_define,
-     .info = info_node_device_define,
+     .info = &info_node_device_define,
      .flags = 0
     },
     {.name = "nodedev-undefine",
      .handler = cmdNodeDeviceUndefine,
      .opts = opts_node_device_undefine,
-     .info = info_node_device_undefine,
+     .info = &info_node_device_undefine,
      .flags = 0
     },
     {.name = "nodedev-start",
      .handler = cmdNodeDeviceStart,
      .opts = opts_node_device_start,
-     .info = info_node_device_start,
+     .info = &info_node_device_start,
      .flags = 0
     },
     {.name = "nodedev-autostart",
      .handler = cmdNodeDeviceAutostart,
      .opts = opts_node_device_autostart,
-     .info = info_node_device_autostart,
+     .info = &info_node_device_autostart,
      .flags = 0
     },
     {.name = "nodedev-info",
      .handler = cmdNodeDeviceInfo,
      .opts = opts_node_device_info,
-     .info = info_node_device_info,
+     .info = &info_node_device_info,
      .flags = 0
     },
     {.name = "nodedev-update",
      .handler = cmdNodeDeviceUpdate,
      .opts = opts_node_device_update,
-     .info = info_node_device_update,
+     .info = &info_node_device_update,
      .flags = 0
     },
     {.name = NULL}
